" Vim syntax file ------------------------------------------- vi:ts=4:ai:sw=4:
" Language:	Telix SALT Script
" Maintainer:	Sean M. McKee <mckee@misslink.net>
" Last change:	8/29/97 - 14:13:37
" Version Info: @(#)TelixSalt.vim	1.2	8/29/97 14:13:37

" Telix is a DOS comm program written by DeltaComm.
" It's scripting language is called SALT.

" Remove any old syntax stuff hanging around
syn clear

" turn case matching off
syn case ignore

"FUNCTIONS
" Character Handling Functions
syn keyword TelixSaltFunction	IsAscii IsAlNum IsAlpha IsCntrl IsDigit
syn keyword TelixSaltFunction	IsLower IsUpper ToLower ToUpper

" Connect Device Operations
syn keyword TelixSaltFunction	Carrier cInp_Cnt cGetC cGetCT cPutC cPutN
syn keyword TelixSaltFunction	cPutS cPutS_TR FlushBuf Get_Baud
syn keyword TelixSaltFunction	Get_DataB Get_Port Get_StopB Hangup
syn keyword TelixSaltFunction	KillConnectDevice MakeConnectDevice
syn keyword TelixSaltFunction	Send_Brk Set_ConnectDevice Set_Port

" File Input/Output Operations
syn keyword TelixSaltFunction	fClearErr fClose fDelete fError fEOF fFlush
syn keyword TelixSaltFunction	fGetC fGetS FileAttr FileFind FileSize
syn keyword TelixSaltFunction	FileTime fnStrip fOpen fPutC fPutS fRead
syn keyword TelixSaltFunction	fRename fSeek fTell fWrite

" File Transfers and Logs
syn keyword TelixSaltFunction	Capture Capture_Stat Printer Receive Send
syn keyword TelixSaltFunction	Set_DefProt UsageLog Usage_Stat UStamp

" Input String Matching
syn keyword TelixSaltFunction	Track Track_AddChr Track_Free Track_Hit
syn keyword TelixSaltFunction	WaitFor

" Keyboard Operations
syn keyword TelixSaltFunction	InKey InKeyW KeyGet KeyLoad KeySave KeySet

" Miscellaneous Functions
syn keyword TelixSaltFunction	ChatMode Dos Dial DosFunction ExitTelix
syn keyword TelixSaltFunction	GetEnv GetFon HelpScreen LoadFon NewDir
syn keyword TelixSaltFunction	Randon Redial RedirectDOS Run
syn keyword TelixSaltFunction	Set_Terminal Show_Directory TelixVersion
syn keyword TelixSaltFunction	Terminal TransTab Update_Term

" Script Management
syn keyword TelixSaltFunction	ArgCount Call CallD CompileScript GetRunPath
syn keyword TelixSaltFunction	Is_Loaded Load_Scr ScriptVersion
syn keyword TelixSaltFunction	TelixForWindows Unload_Scr

" Sound Functions
syn keyword TelixSaltFunction	Alarm PlayWave Tone

" String Handling
syn keyword TelixSaltFunction	CopyChrs CopyStr DelChrs GetS GetSXY
syn keyword TelixSaltFunction	InputBox InsChrs ItoS SetChr StoI StrCat
syn keyword TelixSaltFunction	StrChr StrCompI StrLen StrLower StrMaxLen
syn keyword TelixSaltFunction	StrPos StrPosI StrUpper SubChr SubChrs
syn keyword TelixSaltFunction	SubStr

" Time, Date, and Timer Operations
syn keyword TelixSaltFunction	CurTime Date Delay Delay_Scr Get_OnlineTime
syn keyword TelixSaltFunction	tDay tHour tMin tMonth tSec tYear Time
syn keyword TelixSaltFunction	Time_Up Timer_Free Time_Restart
syn keyword TelixSaltFunction	Time_Start Time_Total

" Video Operations
syn keyword TelixSaltFunction	Box CNewLine Cursor_OnOff Clear_Scr
syn keyword TelixSaltFunction	GetTermHeight GetTermWidth GetX GetY
syn keyword TelixSaltFunction	GotoXY MsgBox NewLine PrintC PrintC_Trm
syn keyword TelixSaltFunction	PrintN PrintN_Trm PrintS PrintS_Trm
syn keyword TelixSaltFunction	PrintSC PRintSC_Trm
syn keyword TelixSaltFunction	PStrA PStrAXY Scroll Status_Wind vGetChr
syn keyword TelixSaltFunction	vGetChrs vGetChrsA  vPutChr vPutChrs
syn keyword TelixSaltFunction	vPutChrsA vRstrArea vSaveArea

" Dynamic Data Exchange (DDE) Operations
syn keyword TelixSaltFunction	DDEExecute DDEInitate DDEPoke DDERequest
syn keyword TelixSaltFunction	DDETerminate DDETerminateAll
"END FUNCTIONS

"PREDEFINED VARAIABLES
syn keyword TelixSaltSysVar	_add_lf _alarm_on _answerback_str _asc_rcrtrans
syn keyword TelixSaltSysVar	_asc_remabort _asc_rlftrans _asc_scpacing
syn keyword TelixSaltSysVar	_asc_scrtrans _asc_secho _asc_slpacing
syn keyword TelixSaltSysVar	_asc_spacechr _asc_striph _back_color
syn keyword TelixSaltSysVar	_capture_fname _connect_str _dest_bs
syn keyword TelixSaltSysVar	_dial_pause _dial_time _dial_post
syn keyword TelixSaltSysVar	_dial_pref1 _dial_pref2 _dial_pref3
syn keyword TelixSaltSysVar	_dial_pref4 _dir_prog _down_dir
syn keyword TelixSaltSysVar	_entry_bbstype _entry_comment _entry_enum
syn keyword TelixSaltSysVar	_entry_name _entry_num _entry_logonname
syn keyword TelixSaltSysVar	_entry_pass _fore_color _image_file
syn keyword TelixSaltSysVar	_local_echo _mdm_hang_str _mdm_init_str
syn keyword TelixSaltSysVar	_no_connect1 _no_connect2 _no_connect3
syn keyword TelixSaltSysVar	_no_connect4 _no_connect5 _redial_stop
syn keyword TelixSaltSysVar	_scr_chk_key _script_dir _sound_on
syn keyword TelixSaltSysVar	_strip_high _swap_bs _telix_dir _up_dir
syn keyword TelixSaltSysVar	_usage_fname _zmodauto _zmod_rcrash
syn keyword TelixSaltSysVar	_zmod_scrash
"END PREDEFINED VARAIABLES

"TYPE
syn keyword TelixSaltType	str int
"END TYPE

"KEYWORDS
syn keyword TelixSaltStatement	goto break return continue
syn keyword TelixSaltConditional	if then else
syn keyword TelixSaltRepeat		while for do
"END KEYWORDS

syn keyword TelixSaltTodo contained	TODO

" the rest is pretty close to C -----------------------------------------

" String and Character constants
" Highlight special characters (those which have a backslash) differently
syn match   TelixSaltSpecial contained "\^[0-9][0-9][0-9]\|\^."
syn region  TelixSaltString		  start=+"+  skip=+\\\\\|\\"+  end=+"+  contains=TelixSaltSpecial
syn match   TelixSaltCharacter	  "'[^\\]'"
syn match   TelixSaltSpecialCharacter  "'\\.'"

"catch errors caused by wrong parenthesis
syn region	TelixSaltParen		transparent start='(' end=')' contains=ALLBUT,TelixSaltParenError,TelixSaltIncluded,TelixSaltSpecial,TelixSaltTodo
syn match	TelixSaltParenError	")"
syn match 	TelixSaltInParen	contained "[{}]"
hi link TelixSaltParenError TelixSaltError
hi link TelixSaltInParen TelixSaltError

"integer number, or floating point number without a dot and with "f".
syn match  TelixSaltNumber		"\<[0-9]\+\(u\=l\=\|lu\|f\)\>"
"floating point number, with dot, optional exponent
syn match  TelixSaltFloat		"\<[0-9]\+\.[0-9]*\(e[-+]\=[0-9]\+\)\=[fl]\=\>"
"floating point number, starting with a dot, optional exponent
syn match  TelixSaltFloat		"\.[0-9]\+\(e[-+]\=[0-9]\+\)\=[fl]\=\>"
"floating point number, without dot, with exponent
syn match  TelixSaltFloat		"\<[0-9]\+e[-+]\=[0-9]\+[fl]\=\>"
"hex number
syn match  TelixSaltNumber		"0x[0-9a-f]\+\(u\=l\=\|lu\)\>"
"syn match  cIdentifier	"\<[a-z_][a-z0-9_]*\>"

syn region TelixSaltComment		start="/\*"  end="\*/" contains=cTodo
syn match  TelixSaltComment		"//.*" contains=cTodo
syn match  TelixSaltCommentError	"\*/"

syn region TelixSaltPreCondit	start="^[ \t]*#[ \t]*\(if\>\|ifdef\>\|ifndef\>\|elif\>\|else\>\|endif\>\)"  skip="\\$"  end="$" contains=TelixSaltComment,TelixSaltString,TelixSaltCharacter,TelixSaltNumber,TelixSaltCommentError
syn region TelixSaltIncluded contained start=+"+  skip=+\\\\\|\\"+  end=+"+
syn match  TelixSaltIncluded contained "<[^>]*>"
syn match  TelixSaltInclude		"^[ \t]*#[ \t]*include\>[ \t]*["<]" contains=TelixSaltIncluded
"syn match  TelixSalyLineSkip	"\\$"
syn region TelixSaltDefine		start="^[ \t]*#[ \t]*\(define\>\|undef\>\)" skip="\\$" end="$" contains=ALLBUT,TelixSaltPreCondit,TelixSaltIncluded,TelixSaltInclude,TelixSaltDefine,TelixSaltInParen
syn region TelixSaltPreProc		start="^[ \t]*#[ \t]*\(pragma\>\|line\>\|warning\>\|warn\>\|error\>\)" skip="\\$" end="$" contains=ALLBUT,TelixSaltPreCondit,TelixSaltIncluded,TelixSaltInclude,TelixSaltDefine,TelixSaltInParen

" Highlight User Labels
syn region	TelixSaltMulti		transparent start='?' end=':' contains=ALLBUT,TelixSaltIncluded,TelixSaltSpecial,TelixSaltTodo

syn sync ccomment TelixSaltComment minlines=10


if !exists("did_TelixSalt_syntax_inits")
	let did_TelixSalt_syntax_inits = 1

	hi link TelixSaltFunction		Statement
	hi link TelixSaltSysVar			Type
	"hi link TelixSaltLibFunc		UserDefFunc
	"hi link TelixSaltConstants		Type
	"hi link TelixSaltFuncArg		Type
	"hi link TelixSaltOperator		Operator
	"hi link TelixSaltLabel			Label
	"hi link TelixSaltUserLabel		Label
	hi link TelixSaltConditional		Conditional
	hi link TelixSaltRepeat			Repeat
	hi link TelixSaltCharacter		Character
	hi link TelixSaltSpecialCharacter TelixSaltSpecial
	hi link TelixSaltNumber			Number
	hi link TelixSaltFloat			Float
	hi link TelixSaltCommentError	TelixSaltError
	hi link TelixSaltInclude			Include
	hi link TelixSaltPreProc			PreProc
	hi link TelixSaltDefine			Macro
	hi link TelixSaltIncluded		TelixSaltString
	hi link TelixSaltError			Error
	hi link TelixSaltStatement		Statement
	hi link TelixSaltPreCondit		PreCondit
	hi link TelixSaltType			Type
	hi link TelixSaltString			String
	hi link TelixSaltComment			Comment
	hi link TelixSaltSpecial			Special
	hi link TelixSaltTodo			Todo

endif

let b:current_syntax = "telixsalt"

" vim: ts=8
